﻿using System.Security.Claims;

namespace Infrastructure.HttpUserContext;

/// <summary>
/// 用户上下文
/// </summary>
/// <typeparam name="TId"></typeparam>
public interface IUserContext<out TId> where TId : IEquatable<TId>
{
    /// <summary>
    /// 用户primary key的类型
    /// </summary>
    TId Id { get; }

    /// <summary>
    /// 用户名
    /// </summary>
    string Username { get; }

    /// <summary>
    /// 名称
    /// </summary>
    string Name { get; }

    /// <summary>
    /// 邮箱
    /// </summary>
    string Email { get; }

    /// <summary>
    /// 角色id
    /// </summary>
    string[] RoleIds { get; }

    /// <summary>
    /// 访问Ip
    /// </summary>
    string RemoteIpAddress { get; }

    /// <summary>
    /// 生成Jwt token信息
    /// </summary>
    /// <param name="jwtSecurityToken"></param>
    /// <param name="duration"></param>
    /// <param name="schemeName"></param>
    /// <returns></returns>
    JwtTokenInfo GenerateTokenInfo(JwtSecurityToken jwtSecurityToken, double? duration, string schemeName);

    /// <summary>
    /// 从当前用户上下文获取claims
    /// </summary>
    /// <returns></returns>
    IList<Claim> GetClaimsFromUserContext();
}